BOOST_ARCH architecture macros

### `BOOST_ARCH` architecture macros

##### `BOOST_ARCH_ALPHA`

DEC Alpha architecture.

Symbol | Version
--- | ---
`__alpha__` | detection
`__alpha` | detection
`_M_ALPHA` | detection
`__alpha_ev4__` | 4.0.0
`__alpha_ev5__` | 5.0.0
`__alpha_ev6__` | 6.0.0

##### `BOOST_ARCH_ARM`

ARM architecture.

Symbol | Version
--- | ---
`__arm__` | detection
`__arm64` | detection
`__thumb__` | detection
`__TARGET_ARCH_ARM` | detection
`__TARGET_ARCH_THUMB` | detection
`_M_ARM` | detection
`__arm64` | 8.0.0
`__TARGET_ARCH_ARM` | V.0.0
`__TARGET_ARCH_THUMB` | V.0.0
`_M_ARM` | V.0.0

##### `BOOST_ARCH_BLACKFIN`

Blackfin Processors from Analog Devices.

Symbol | Version
--- | ---
`__bfin__` | detection
`__BFIN__` | detection
`bfin` | detection
`BFIN` | detection

##### `BOOST_ARCH_CONVEX`

Convex Computer architecture.

Symbol | Version
--- | ---
`__convex__` | detection
`__convex_c1__` | 1.0.0
`__convex_c2__` | 2.0.0
`__convex_c32__` | 3.2.0
`__convex_c34__` | 3.4.0
`__convex_c38__` | 3.8.0

##### `BOOST_ARCH_IA64`

Intel Itanium 64 architecture.

Symbol | Version
--- | ---
`__ia64__` | detection
`_IA64` | detection
`__IA64__` | detection
`__ia64` | detection
`_M_IA64` | detection
`__itanium__` | detection

##### `BOOST_ARCH_M68K`

Motorola 68k architecture.

Symbol | Version
--- | ---
`__m68k__` | detection
`M68000` | detection
`__mc68060__` | 6.0.0
`mc68060` | 6.0.0
`__mc68060` | 6.0.0
`__mc68040__` | 4.0.0
`mc68040` | 4.0.0
`__mc68040` | 4.0.0
`__mc68030__` | 3.0.0
`mc68030` | 3.0.0
`__mc68030` | 3.0.0
`__mc68020__` | 2.0.0
`mc68020` | 2.0.0
`__mc68020` | 2.0.0
`__mc68010__` | 1.0.0
`mc68010` | 1.0.0
`__mc68010` | 1.0.0
`__mc68000__` | 0.0.1
`mc68000` | 0.0.1
`__mc68000` | 0.0.1

##### `BOOST_ARCH_MIPS`

MIPS architecture.

Symbol | Version
--- | ---
`__mips__` | detection
`__mips` | detection
`__MIPS__` | detection
`__mips` | V.0.0
`_MIPS_ISA_MIPS1` | 1.0.0
`_R3000` | 1.0.0
`_MIPS_ISA_MIPS2` | 2.0.0
`__MIPS_ISA2__` | 2.0.0
`_R4000` | 2.0.0
`_MIPS_ISA_MIPS3` | 3.0.0
`__MIPS_ISA3__` | 3.0.0
`_MIPS_ISA_MIPS4` | 4.0.0
`__MIPS_ISA4__` | 4.0.0

##### `BOOST_ARCH_PARISK`

HP/PA RISC architecture.

Symbol | Version
--- | ---
`__hppa__` | detection
`__hppa` | detection
`__HPPA__` | detection
`_PA_RISC1_0` | 1.0.0
`_PA_RISC1_1` | 1.1.0
`__HPPA11__` | 1.1.0
`__PA7100__` | 1.1.0
`_PA_RISC2_0` | 2.0.0
`__RISC2_0__` | 2.0.0
`__HPPA20__` | 2.0.0
`__PA8000__` | 2.0.0

##### `BOOST_ARCH_PPC`

PowerPC architecture.

Symbol | Version
--- | ---
`__powerpc` | detection
`__powerpc__` | detection
`__POWERPC__` | detection
`__ppc__` | detection
`_M_PPC` | detection
`_ARCH_PPC` | detection
`__PPCGECKO__` | detection
`__PPCBROADWAY__` | detection
`_XENON` | detection
`__ppc601__` | 6.1.0
`_ARCH_601` | 6.1.0
`__ppc603__` | 6.3.0
`_ARCH_603` | 6.3.0
`__ppc604__` | 6.4.0
`__ppc604__` | 6.4.0

##### `BOOST_ARCH_PYRAMID`

Pyramid 9810 architecture.

Symbol | Version
--- | ---
`pyr` | detection

##### `BOOST_ARCH_RS6000`

RS/6000 architecture.

Symbol | Version
--- | ---
`__THW_RS6000` | detection
`_IBMR2` | detection
`_POWER` | detection
`_ARCH_PWR` | detection
`_ARCH_PWR2` | detection

##### `BOOST_ARCH_SPARC`

SPARC architecture.

Symbol | Version
--- | ---
`__sparc__` | detection
`__sparc` | detection
`__sparcv9` | 9.0.0
`__sparcv8` | 8.0.0

##### `BOOST_ARCH_SH`

SuperH architecture: If available versions [1-5] are specifically detected.

Symbol | Version
--- | ---
`__sh__` | detection
`__SH5__` | 5.0.0
`__SH4__` | 4.0.0
`__sh3__` | 3.0.0
`__SH3__` | 3.0.0
`__sh2__` | 2.0.0
`__sh1__` | 1.0.0

##### `BOOST_ARCH_SYS370`

System/370 architecture.

Symbol | Version
--- | ---
`__370__` | detection
`__THW_370__` | detection

##### `BOOST_ARCH_SYS390`

System/390 architecture.

Symbol | Version
--- | ---
`__s390__` | detection
`__s390x__` | detection

##### `BOOST_ARCH_X86`

Intel x86 architecture. This is a category to indicate that either `BOOST_ARCH_X86_32` or `BOOST_ARCH_X86_64` is detected.

##### `BOOST_ARCH_Z`

z/Architecture architecture.

Symbol | Version
--- | ---
`__SYSC_ZARCH__` | detection

##### `BOOST_ARCH_X86_32`

Intel x86 architecture: If available versions [3-6] are specifically detected.

Symbol | Version
--- | ---
`i386` | detection
`__i386__` | detection
`__i486__` | detection
`__i586__` | detection
`__i686__` | detection
`__i386` | detection
`_M_IX86` | detection
`_X86_` | detection
`__THW_INTEL__` | detection
`__I86__` | detection
`__INTEL__` | detection
`__I86__` | V.0.0
`_M_IX86` | V.0.0
`__i686__` | 6.0.0
`__i586__` | 5.0.0
`__i486__` | 4.0.0
`__i386__` | 3.0.0

##### `BOOST_ARCH_X86_64`

Intel IA-64 architecture.

Symbol | Version
--- | ---
`__x86_64` | detection
`__x86_64__` | detection
`__amd64__` | detection
`__amd64` | detection
`_M_X64` | detection